==> newsflash-5.x-1.2.tar.gz: newsflash/page.tpl.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="<?php print $language ?>" xml:lang="<?php print $language ?>">

<head>
  <title><?php print $head_title ?></title>
  <?php print $head ?>
  <?php print $styles ?>
  <?php print $scripts ?>
  <script type="text/javascript"><?php /* Needed to avoid Flash of Unstyle Content in IE */ ?> </script>
  
   <?php if (theme_get_setting('newsflash_width')) { ?>
	<style type="text/css">
      	#page {
			width : <?php print theme_get_setting('newsflash_fixedwidth') ?>px;
		}
      </style>
   <?php } else { ?>
	<style type="text/css">
      	#page {
      width: 95%;
		}
      </style>
   <?php }  ?>

<?php if (theme_get_setting('newsflash_iepngfix')) { ?>
<!--[if lte IE 6]>
<script type="text/javascript"> 
    $(document).ready(function(){ 
        $(document).pngFix(); 
    }); 
</script> 
<![endif]-->
<?php } ?>

<?php 
$style = theme_get_setting('newsflash_style');
if (!$style)
{
   $style = 'blue';
}
 ?>

  
</head>

<body>

<div id="page">

<table border="0" cellpadding="0" cellspacing="0" id="header">
  <tr>
    <td id="logo">
      <?php if ($logo) { ?><a href="<?php print $base_path ?>" title="<?php print t('Home') ?>"><img src="<?php print $logo ?>" alt="<?php print t('Home') ?>" /></a><?php } ?>
      <?php if ($site_name) { ?><h1 class='site-name'><a href="<?php print $base_path ?>" title="<?php print t('Home') ?>"><?php print $site_name ?></a></h1><?php } ?>
      <?php if ($site_slogan) { ?><div class='site-slogan'><?php print $site_slogan ?></div><?php } ?>
    </td>
    <td id="menu">
      <?php if (isset($secondary_links)) { ?><?php print theme('links', $secondary_links, array('class' =>'links', 'id' => 'subnavlist')) ?><?php } ?>
      <?php if (isset($primary_links)) { ?><?php print theme('links', $primary_links, array('class' =>'links', 'id' => 'navlist')) ?><?php } ?>
      <?php print $search_box ?>
    </td>
  </tr>
  <tr>
    <td colspan="2"><div><?php print $header ?></div></td>
  </tr>
</table>

	<?php
         $section1count = 0;
         $user1count = 0;
         $user2count = 0;
         $user3count = 0;

         if ($user1)
         {
            $section1count++;
            $user1count++;
         }

         if ($user2)
         {
            $section1count++;
            $user2count++;
         }
         
         if ($user3)
         {
            $section1count++;
            $user3count++;
         }
      ?>

      <?php if ($section1count): ?>
         <?php $section1width = 'width' . floor(99 / $section1count); ?>
         <?php $block2div = ($user1count and ($user2count or $user3count)) ? " divider" : ""; ?>
         <?php $block3div = ($user3count and ($user1count or $user2count)) ? " divider" : ""; ?>
	   <div class="clr" id="section1">

         <table class="sections" cellspacing="0" cellpadding="0">
            <tr valign="top">

            <?php if ($user1): ?>
               <td class="section <?php echo $section1width ?>">
                  <?php print $user1; ?>
               </td>
            <?php endif; ?>  

            <?php if ($user2): ?>
               <td class="section <?php echo $section1width . $block2div; ?>">
                  <?php print $user2; ?>
               </td>
            <?php endif; ?>  

            <?php if ($user3): ?>
               <td class="section <?php echo $section1width . $block3div; ?>">
                  <?php print $user3; ?>
               </td>
            <?php endif; ?>  

            </tr>
         </table>

         </div>  <!-- /section1 -->
      <?php endif; ?>



<table border="0" cellpadding="0" cellspacing="0" id="content">
  <tr>
    <?php if ($sidebar_left) { ?><td id="sidebar-left">
      <?php print $sidebar_left ?>
    </td><?php } ?>
    <td valign="top">
      <?php if ($mission) { ?><div id="mission"><?php print $mission ?></div><?php } ?>
      <div id="main">

        <?php if (theme_get_setting('newsflash_breadcrumb')): ?>
          <?php if ($breadcrumb): ?>
            <div id="breadcrumb"> <?php print $breadcrumb; ?> </div>
          <?php endif; ?>
        <?php endif; ?>

        <?php if ($content_top):?><div id="content-top"><?php print $content_top; ?></div><?php endif; ?>
        <h1 class="title"><?php print $title ?></h1>
        <div class="tabs"><?php print $tabs ?></div>
        <?php print $help ?>
        <?php print $messages ?>
        <?php print $content; ?>
        <?php print $feed_icons; ?>
        <?php if ($content_bottom): ?><div id="content-bottom"><?php print $content_bottom; ?></div><?php endif; ?>
      </div>
    </td>
    <?php if ($sidebar_right) { ?><td id="sidebar-right">
      <?php print $sidebar_right ?>
    </td><?php } ?>
  </tr>
</table>



	<?php
         $section2count = 0;
         $user4count = 0;
         $user5count = 0;
         $user6count = 0;

         if ($user4)
         {
            $section2count++;
            $user4count++;
         }

         if ($user5)
         {
            $section2count++;
            $user5count++;
         }
         
         if ($user6)
         {
            $section2count++;
            $user6count++;
         }
      ?>

      <?php if ($section2count): ?>
         <?php $section2width = 'width' . floor(99 / $section2count); ?>
         <?php $block2div = ($user4count and ($user5count or $user6count)) ? " divider" : ""; ?>
         <?php $block3div = ($user6count and ($user4count or $user5count)) ? " divider" : ""; ?>
	   <div class="clr" id="section2">

       <table class="sections" cellspacing="0" cellpadding="0">
            <tr valign="top">

            <?php if ($user4): ?>
               <td class="section <?php echo $section2width ?>">
                  <?php print $user4; ?>
               </td>
            <?php endif; ?>  

            <?php if ($user5): ?>
               <td class="section <?php echo $section2width . $block2div; ?>">
                  <?php print $user5; ?>
               </td>
            <?php endif; ?>  

            <?php if ($user6): ?>
               <td class="section <?php echo $section2width . $block3div; ?>">
                  <?php print $user6; ?>
               </td>
            <?php endif; ?>  

            </tr>
         </table>

         </div>  <!-- /section2 -->
      <?php endif; ?>

<div id="footer">
  <?php print $footer_message ?>
 
  <?php $logoPath = drupal_get_path('theme', 'newsflash') . '/images/' . $style . '/RoopleThemeLogo.png'; ?>
	<br /><a href="http://www.roopletheme.com" title="RoopleTheme!"><img src="<?php print $logoPath ?>" alt="RoopleTheme"/></a>

</div>
<?php print $closure ?>

</div>

</body>
</html>

==> newsflash-5.x-1.3.tar.gz: newsflash/page.tpl.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="<?php print $language ?>" xml:lang="<?php print $language ?>">

<head>
  <title><?php print $head_title ?></title>
  <?php print $head ?>
  <?php print $styles ?>
  <?php print $scripts ?>
  <script type="text/javascript"><?php /* Needed to avoid Flash of Unstyle Content in IE */ ?> </script>
  
   <?php if (theme_get_setting('newsflash_width')) { ?>
	<style type="text/css">
      	#page {
			width : <?php print theme_get_setting('newsflash_fixedwidth') ?>px;
		}
      </style>
   <?php } else { ?>
	<style type="text/css">
      	#page {
      width: 95%;
		}
      </style>
   <?php }  ?>

<?php if (theme_get_setting('newsflash_iepngfix')) { ?>
<!--[if lte IE 6]>
<script type="text/javascript"> 
    $(document).ready(function(){ 
        $(document).pngFix(); 
    }); 
</script> 
<![endif]-->
<?php } ?>

<?php 
$style = theme_get_setting('newsflash_style');
if (!$style)
{
   $style = 'blue';
}
 ?>

  
</head>

<body>

<div id="page">

<table border="0" cellpadding="0" cellspacing="0" id="header">
  <tr>
    <td id="logo">
      <?php if ($logo) { ?><a href="<?php print $base_path ?>" title="<?php print t('Home') ?>"><img src="<?php print $logo ?>" alt="<?php print t('Home') ?>" /></a><?php } ?>
      <?php if ($site_name) { ?><h1 class='site-name'><a href="<?php print $base_path ?>" title="<?php print t('Home') ?>"><?php print $site_name ?></a></h1><?php } ?>
      <?php if ($site_slogan) { ?><div class='site-slogan'><?php print $site_slogan ?></div><?php } ?>
    </td>
    <td id="menu">
      <?php if (isset($secondary_links)) { ?><?php print theme('links', $secondary_links, array('class' =>'links', 'id' => 'subnavlist')) ?><?php } ?>
      <?php if (isset($primary_links)) { ?><?php print theme('links', $primary_links, array('class' =>'links', 'id' => 'navlist')) ?><?php } ?>
      <?php print $search_box ?>
    </td>
  </tr>
  <tr>
    <td colspan="2"><div><?php print $header ?></div></td>
  </tr>
</table>

	<?php
         $section1count = 0;
         $user1count = 0;
         $user2count = 0;
         $user3count = 0;

         if ($user1)
         {
            $section1count++;
            $user1count++;
         }

         if ($user2)
         {
            $section1count++;
            $user2count++;
         }
         
         if ($user3)
         {
            $section1count++;
            $user3count++;
         }
      ?>

      <?php if ($section1count): ?>
         <?php $section1width = 'width' . floor(99 / $section1count); ?>
         <?php $block2div = ($user1count and ($user2count or $user3count)) ? " divider" : ""; ?>
         <?php $block3div = ($user3count and ($user1count or $user2count)) ? " divider" : ""; ?>
	   <div class="clr" id="section1">

         <table class="sections" cellspacing="0" cellpadding="0">
            <tr valign="top">

            <?php if ($user1): ?>
               <td class="section <?php echo $section1width ?>">
                  <?php print $user1; ?>
               </td>
            <?php endif; ?>  

            <?php if ($user2): ?>
               <td class="section <?php echo $section1width . $block2div; ?>">
                  <?php print $user2; ?>
               </td>
            <?php endif; ?>  

            <?php if ($user3): ?>
               <td class="section <?php echo $section1width . $block3div; ?>">
                  <?php print $user3; ?>
               </td>
            <?php endif; ?>  

            </tr>
         </table>

         </div>  <!-- /section1 -->
      <?php endif; ?>



<table border="0" cellpadding="0" cellspacing="0" id="content">
  <tr>
    <?php if ($sidebar_left) { ?><td id="sidebar-left">
      <?php print $sidebar_left ?>
    </td><?php } ?>
    <td valign="top">
      <?php if ($mission) { ?><div id="mission"><?php print $mission ?></div><?php } ?>
      <div id="main">

        <?php if (theme_get_setting('newsflash_breadcrumb')): ?>
          <?php if ($breadcrumb): ?>
            <div id="breadcrumb"> <?php print $breadcrumb; ?> </div>
          <?php endif; ?>
        <?php endif; ?>

        <?php if ($content_top):?><div id="content-top"><?php print $content_top; ?></div><?php endif; ?>
        <h1 class="title"><?php print $title ?></h1>
        <div class="tabs"><?php print $tabs ?></div>
        <?php print $help ?>
        <?php print $messages ?>
        <?php print $content; ?>
        <?php print $feed_icons; ?>
        <?php if ($content_bottom): ?><div id="content-bottom"><?php print $content_bottom; ?></div><?php endif; ?>
      </div>
    </td>
    <?php if ($sidebar_right) { ?><td id="sidebar-right">
      <?php print $sidebar_right ?>
    </td><?php } ?>
  </tr>
</table>



	<?php
         $section2count = 0;
         $user4count = 0;
         $user5count = 0;
         $user6count = 0;

         if ($user4)
         {
            $section2count++;
            $user4count++;
         }

         if ($user5)
         {
            $section2count++;
            $user5count++;
         }
         
         if ($user6)
         {
            $section2count++;
            $user6count++;
         }
      ?>

      <?php if ($section2count): ?>
         <?php $section2width = 'width' . floor(99 / $section2count); ?>
         <?php $block2div = ($user4count and ($user5count or $user6count)) ? " divider" : ""; ?>
         <?php $block3div = ($user6count and ($user4count or $user5count)) ? " divider" : ""; ?>
	   <div class="clr" id="section2">

       <table class="sections" cellspacing="0" cellpadding="0">
            <tr valign="top">

            <?php if ($user4): ?>
               <td class="section <?php echo $section2width ?>">
                  <?php print $user4; ?>
               </td>
            <?php endif; ?>  

            <?php if ($user5): ?>
               <td class="section <?php echo $section2width . $block2div; ?>">
                  <?php print $user5; ?>
               </td>
            <?php endif; ?>  

            <?php if ($user6): ?>
               <td class="section <?php echo $section2width . $block3div; ?>">
                  <?php print $user6; ?>
               </td>
            <?php endif; ?>  

            </tr>
         </table>

         </div>  <!-- /section2 -->
      <?php endif; ?>

<div id="footer">
  <?php print $footer_message ?>
 
  <?php $logoPath = base_path() . path_to_theme() . '/images/' . $style . '/RoopleThemeLogo.png'; ?>
	<br /><a href="http://www.roopletheme.com" title="RoopleTheme!"><img src="<?php print $logoPath ?>" alt="RoopleTheme"/></a>

</div>
<?php print $closure ?>

</div>

</body>
</html>
